Index: wp-includes/functions.php
===================================================================
--- wp-includes/functions.php	(revision 23297)
+++ wp-includes/functions.php	(working copy)
@@ -2848,12 +2848,13 @@
  *   trigger or false to not trigger error.
  *
  * @param string $function The function that was called
  * @param string $version The version of WordPress that deprecated the function
  * @param string $replacement Optional. The function that should have been called
+ * @param string $package Optional. The package to which $function belongs
  */
-function _deprecated_function( $function, $version, $replacement = null ) {
+function _deprecated_function( $function, $version, $replacement = null, $package = 'core' ) {
 
-	do_action( 'deprecated_function_run', $function, $replacement, $version );
+	do_action( 'deprecated_function_run', $function, $replacement, $version, $package );
 
 	// Allow plugin to filter the output error trigger
 	if ( WP_DEBUG && apply_filters( 'deprecated_function_trigger_error', true ) ) {
@@ -2886,13 +2887,14 @@
  *   trigger or false to not trigger error.
  *
  * @param string $file The file that was included
  * @param string $version The version of WordPress that deprecated the file
  * @param string $replacement Optional. The file that should have been included based on ABSPATH
  * @param string $message Optional. A message regarding the change
+ * @param string $package Optional. The package to which $function belongs
  */
-function _deprecated_file( $file, $version, $replacement = null, $message = '' ) {
+function _deprecated_file( $file, $version, $replacement = null, $message = '', $package = 'core' ) {
 
-	do_action( 'deprecated_file_included', $file, $replacement, $version, $message );
+	do_action( 'deprecated_file_included', $file, $replacement, $version, $message, $package );
 
 	// Allow plugin to filter the output error trigger
 	if ( WP_DEBUG && apply_filters( 'deprecated_file_trigger_error', true ) ) {
@@ -2912,7 +2914,7 @@
  * For example:
  * <code>
  * if ( !empty($deprecated) )
- * 	_deprecated_argument( __FUNCTION__, '3.0' );
+ * 	_deprecated_argument( __FUNCTION__, '3.0', 'core' );
  * </code>
  *
  * There is a hook deprecated_argument_run that will be called that can be used
@@ -2932,12 +2934,13 @@
  *   trigger or false to not trigger error.
  *
  * @param string $function The function that was called
  * @param string $version The version of WordPress that deprecated the argument used
  * @param string $message Optional. A message regarding the change.
+ * @param string $package Optional. The package to which $function belongs
  */
-function _deprecated_argument( $function, $version, $message = null ) {
+function _deprecated_argument( $function, $version, $message = null, $package = 'core' ) {
 
-	do_action( 'deprecated_argument_run', $function, $message, $version );
+	do_action( 'deprecated_argument_run', $function, $message, $version, $package );
 
 	// Allow plugin to filter the output error trigger
 	if ( WP_DEBUG && apply_filters( 'deprecated_argument_trigger_error', true ) ) {
@@ -2848,12 +2848,13 @@
  *
  * @param string $function The function that was called
- * @param string $version The version of WordPress that deprecated the function
+ * @param string $version The version of $package that deprecated the function
  * @param string $replacement Optional. The function that should have been called
@@ -2886,13 +2887,14 @@
  *
  * @param string $file The file that was included
- * @param string $version The version of WordPress that deprecated the file
+ * @param string $version The version of $package that deprecated the file
  * @param string $replacement Optional. The file that should have been included based on ABSPATH
  * @param string $message Optional. A message regarding the change
@@ -2932,12 +2934,13 @@
  *
  * @param string $function The function that was called
- * @param string $version The version of WordPress that deprecated the argument used
+ * @param string $version The version of $package that deprecated the argument used
  * @param string $message Optional. A message regarding the change.
